@@ -19,7 +19,7 @@ use XSLoader;
 our @EXPORT    = qw();
 our @EXPORT_OK = qw(load);
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 XSLoader::load 'Sys::CpuLoad', $VERSION;
 
@@ -46,7 +46,7 @@ sub import {
         };
 
     }
-    elsif ( $os eq 'freebsd' || $os eq 'openbsd' ) {
+    elsif ( $os =~ /^(darwin|freebsd|openbsd)$/ ) {
 
         no strict 'refs'; ## no critic (ProhibitNoStrict)
 
@@ -95,7 +95,7 @@ Sys::CpuLoad - retrieve system load averages
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -155,6 +155,12 @@ Clinton Wong <clintdw@cpan.org>
 
 =back
 
+=head1 CONTRIBUTOR
+
+=for stopwords Vincent Lefèvre
+
+Vincent Lefèvre <vincent@vinc17.net>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 1999-2002, 2020 by Clinton Wong <clintdw@cpan.org>.
